==> org-lsst-sal-camera-2.2.10-sources.jar: org/lsst/sal/camera/telemetry/Refrig_Cryo6Telemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Refrig_Cryo6Telemetry extends CameraTelemetry {
  private final double dischrgtmp_P;

  private final double dischrgtmp_M;

  private final double dischrgPrs;

  private final double suctiontmp_P;

  private final double suctiontmp_M;

  private final double suctionPrs;

  private final double oilLevel;

  private final double compVoltage;

  private final double compCurrent;

  private final double compPower;

  private final double waterInTmp;

  private final double waterOutTmp;

  private final double afterCoolTmp;

  private final double phaseSepTmp;

  private final double oilSepTmp;

  private final double surgeTankTmp;

  private final double fanSpeed;

  public Refrig_Cryo6Telemetry(double dischrgtmp_P, double dischrgtmp_M, double dischrgPrs,
      double suctiontmp_P, double suctiontmp_M, double suctionPrs, double oilLevel,
      double compVoltage, double compCurrent, double compPower, double waterInTmp,
      double waterOutTmp, double afterCoolTmp, double phaseSepTmp, double oilSepTmp,
      double surgeTankTmp, double fanSpeed) {
    this.dischrgtmp_P = dischrgtmp_P;
    this.dischrgtmp_M = dischrgtmp_M;
    this.dischrgPrs = dischrgPrs;
    this.suctiontmp_P = suctiontmp_P;
    this.suctiontmp_M = suctiontmp_M;
    this.suctionPrs = suctionPrs;
    this.oilLevel = oilLevel;
    this.compVoltage = compVoltage;
    this.compCurrent = compCurrent;
    this.compPower = compPower;
    this.waterInTmp = waterInTmp;
    this.waterOutTmp = waterOutTmp;
    this.afterCoolTmp = afterCoolTmp;
    this.phaseSepTmp = phaseSepTmp;
    this.oilSepTmp = oilSepTmp;
    this.surgeTankTmp = surgeTankTmp;
    this.fanSpeed = fanSpeed;
  }

  public double getDischrgtmp_P() {
    return dischrgtmp_P;
  }

  public double getDischrgtmp_M() {
    return dischrgtmp_M;
  }

  public double getDischrgPrs() {
    return dischrgPrs;
  }

  public double getSuctiontmp_P() {
    return suctiontmp_P;
  }

  public double getSuctiontmp_M() {
    return suctiontmp_M;
  }

  public double getSuctionPrs() {
    return suctionPrs;
  }

  public double getOilLevel() {
    return oilLevel;
  }

  public double getCompVoltage() {
    return compVoltage;
  }

  public double getCompCurrent() {
    return compCurrent;
  }

  public double getCompPower() {
    return compPower;
  }

  public double getWaterInTmp() {
    return waterInTmp;
  }

  public double getWaterOutTmp() {
    return waterOutTmp;
  }

  public double getAfterCoolTmp() {
    return afterCoolTmp;
  }

  public double getPhaseSepTmp() {
    return phaseSepTmp;
  }

  public double getOilSepTmp() {
    return oilSepTmp;
  }

  public double getSurgeTankTmp() {
    return surgeTankTmp;
  }

  public double getFanSpeed() {
    return fanSpeed;
  }

  @Override
  public String toString() {
    return "Refrig_Cryo6Telemetry{" + "dischrgtmp_P=" + dischrgtmp_P +
        ", dischrgtmp_M=" + dischrgtmp_M +", dischrgPrs=" + dischrgPrs +
        ", suctiontmp_P=" + suctiontmp_P +", suctiontmp_M=" + suctiontmp_M +
        ", suctionPrs=" + suctionPrs +", oilLevel=" + oilLevel +", compVoltage=" + compVoltage +
        ", compCurrent=" + compCurrent +", compPower=" + compPower +", waterInTmp=" + waterInTmp +
        ", waterOutTmp=" + waterOutTmp +", afterCoolTmp=" + afterCoolTmp +
        ", phaseSepTmp=" + phaseSepTmp +", oilSepTmp=" + oilSepTmp +
        ", surgeTankTmp=" + surgeTankTmp +", fanSpeed=" + fanSpeed +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private double dischrgtmp_P;

    private double dischrgtmp_M;

    private double dischrgPrs;

    private double suctiontmp_P;

    private double suctiontmp_M;

    private double suctionPrs;

    private double oilLevel;

    private double compVoltage;

    private double compCurrent;

    private double compPower;

    private double waterInTmp;

    private double waterOutTmp;

    private double afterCoolTmp;

    private double phaseSepTmp;

    private double oilSepTmp;

    private double surgeTankTmp;

    private double fanSpeed;

    private Builder() {
    }

    public Builder dischrgtmp_P(double dischrgtmp_P) {
      this.dischrgtmp_P = dischrgtmp_P;
      return this;
    }

    public Builder dischrgtmp_M(double dischrgtmp_M) {
      this.dischrgtmp_M = dischrgtmp_M;
      return this;
    }

    public Builder dischrgPrs(double dischrgPrs) {
      this.dischrgPrs = dischrgPrs;
      return this;
    }

    public Builder suctiontmp_P(double suctiontmp_P) {
      this.suctiontmp_P = suctiontmp_P;
      return this;
    }

    public Builder suctiontmp_M(double suctiontmp_M) {
      this.suctiontmp_M = suctiontmp_M;
      return this;
    }

    public Builder suctionPrs(double suctionPrs) {
      this.suctionPrs = suctionPrs;
      return this;
    }

    public Builder oilLevel(double oilLevel) {
      this.oilLevel = oilLevel;
      return this;
    }

    public Builder compVoltage(double compVoltage) {
      this.compVoltage = compVoltage;
      return this;
    }

    public Builder compCurrent(double compCurrent) {
      this.compCurrent = compCurrent;
      return this;
    }

    public Builder compPower(double compPower) {
      this.compPower = compPower;
      return this;
    }

    public Builder waterInTmp(double waterInTmp) {
      this.waterInTmp = waterInTmp;
      return this;
    }

    public Builder waterOutTmp(double waterOutTmp) {
      this.waterOutTmp = waterOutTmp;
      return this;
    }

    public Builder afterCoolTmp(double afterCoolTmp) {
      this.afterCoolTmp = afterCoolTmp;
      return this;
    }

    public Builder phaseSepTmp(double phaseSepTmp) {
      this.phaseSepTmp = phaseSepTmp;
      return this;
    }

    public Builder oilSepTmp(double oilSepTmp) {
      this.oilSepTmp = oilSepTmp;
      return this;
    }

    public Builder surgeTankTmp(double surgeTankTmp) {
      this.surgeTankTmp = surgeTankTmp;
      return this;
    }

    public Builder fanSpeed(double fanSpeed) {
      this.fanSpeed = fanSpeed;
      return this;
    }

    public Refrig_Cryo6Telemetry build() {
      return new Refrig_Cryo6Telemetry(dischrgtmp_P, dischrgtmp_M, dischrgPrs, suctiontmp_P, suctiontmp_M, suctionPrs, oilLevel, compVoltage, compCurrent, compPower, waterInTmp, waterOutTmp, afterCoolTmp, phaseSepTmp, oilSepTmp, surgeTankTmp, fanSpeed);
    }
  }
}

==> org-lsst-sal-camera-2.5.8-sources.jar: org/lsst/sal/camera/telemetry/Refrig_Cryo6Telemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Refrig_Cryo6Telemetry extends CameraTelemetry {
  private final double afterCoolTmp;

  private final double compCurrent;

  private final double compPower;

  private final double compVoltage;

  private final double dischrgPrs;

  private final double dischrgtmp_M;

  private final double dischrgtmp_P;

  private final double fanSpeed;

  private final double oilLevel;

  private final double oilSepTmp;

  private final double phaseSepTmp;

  private final double suctionPrs;

  private final double suctiontmp_M;

  private final double suctiontmp_P;

  private final double surgeTankTmp;

  private final double waterInTmp;

  private final double waterOutTmp;

  public Refrig_Cryo6Telemetry(double afterCoolTmp, double compCurrent, double compPower,
      double compVoltage, double dischrgPrs, double dischrgtmp_M, double dischrgtmp_P,
      double fanSpeed, double oilLevel, double oilSepTmp, double phaseSepTmp, double suctionPrs,
      double suctiontmp_M, double suctiontmp_P, double surgeTankTmp, double waterInTmp,
      double waterOutTmp) {
    this.afterCoolTmp = afterCoolTmp;
    this.compCurrent = compCurrent;
    this.compPower = compPower;
    this.compVoltage = compVoltage;
    this.dischrgPrs = dischrgPrs;
    this.dischrgtmp_M = dischrgtmp_M;
    this.dischrgtmp_P = dischrgtmp_P;
    this.fanSpeed = fanSpeed;
    this.oilLevel = oilLevel;
    this.oilSepTmp = oilSepTmp;
    this.phaseSepTmp = phaseSepTmp;
    this.suctionPrs = suctionPrs;
    this.suctiontmp_M = suctiontmp_M;
    this.suctiontmp_P = suctiontmp_P;
    this.surgeTankTmp = surgeTankTmp;
    this.waterInTmp = waterInTmp;
    this.waterOutTmp = waterOutTmp;
  }

  public double getAfterCoolTmp() {
    return afterCoolTmp;
  }

  public double getCompCurrent() {
    return compCurrent;
  }

  public double getCompPower() {
    return compPower;
  }

  public double getCompVoltage() {
    return compVoltage;
  }

  public double getDischrgPrs() {
    return dischrgPrs;
  }

  public double getDischrgtmp_M() {
    return dischrgtmp_M;
  }

  public double getDischrgtmp_P() {
    return dischrgtmp_P;
  }

  public double getFanSpeed() {
    return fanSpeed;
  }

  public double getOilLevel() {
    return oilLevel;
  }

  public double getOilSepTmp() {
    return oilSepTmp;
  }

  public double getPhaseSepTmp() {
    return phaseSepTmp;
  }

  public double getSuctionPrs() {
    return suctionPrs;
  }

  public double getSuctiontmp_M() {
    return suctiontmp_M;
  }

  public double getSuctiontmp_P() {
    return suctiontmp_P;
  }

  public double getSurgeTankTmp() {
    return surgeTankTmp;
  }

  public double getWaterInTmp() {
    return waterInTmp;
  }

  public double getWaterOutTmp() {
    return waterOutTmp;
  }

  @Override
  public String toString() {
    return "Refrig_Cryo6Telemetry{" + "afterCoolTmp=" + afterCoolTmp +
        ", compCurrent=" + compCurrent +", compPower=" + compPower +", compVoltage=" + compVoltage +
        ", dischrgPrs=" + dischrgPrs +", dischrgtmp_M=" + dischrgtmp_M +
        ", dischrgtmp_P=" + dischrgtmp_P +", fanSpeed=" + fanSpeed +", oilLevel=" + oilLevel +
        ", oilSepTmp=" + oilSepTmp +", phaseSepTmp=" + phaseSepTmp +", suctionPrs=" + suctionPrs +
        ", suctiontmp_M=" + suctiontmp_M +", suctiontmp_P=" + suctiontmp_P +
        ", surgeTankTmp=" + surgeTankTmp +", waterInTmp=" + waterInTmp +
        ", waterOutTmp=" + waterOutTmp +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private double afterCoolTmp;

    private double compCurrent;

    private double compPower;

    private double compVoltage;

    private double dischrgPrs;

    private double dischrgtmp_M;

    private double dischrgtmp_P;

    private double fanSpeed;

    private double oilLevel;

    private double oilSepTmp;

    private double phaseSepTmp;

    private double suctionPrs;

    private double suctiontmp_M;

    private double suctiontmp_P;

    private double surgeTankTmp;

    private double waterInTmp;

    private double waterOutTmp;

    private Builder() {
    }

    public Builder afterCoolTmp(double afterCoolTmp) {
      this.afterCoolTmp = afterCoolTmp;
      return this;
    }

    public Builder compCurrent(double compCurrent) {
      this.compCurrent = compCurrent;
      return this;
    }

    public Builder compPower(double compPower) {
      this.compPower = compPower;
      return this;
    }

    public Builder compVoltage(double compVoltage) {
      this.compVoltage = compVoltage;
      return this;
    }

    public Builder dischrgPrs(double dischrgPrs) {
      this.dischrgPrs = dischrgPrs;
      return this;
    }

    public Builder dischrgtmp_M(double dischrgtmp_M) {
      this.dischrgtmp_M = dischrgtmp_M;
      return this;
    }

    public Builder dischrgtmp_P(double dischrgtmp_P) {
      this.dischrgtmp_P = dischrgtmp_P;
      return this;
    }

    public Builder fanSpeed(double fanSpeed) {
      this.fanSpeed = fanSpeed;
      return this;
    }

    public Builder oilLevel(double oilLevel) {
      this.oilLevel = oilLevel;
      return this;
    }

    public Builder oilSepTmp(double oilSepTmp) {
      this.oilSepTmp = oilSepTmp;
      return this;
    }

    public Builder phaseSepTmp(double phaseSepTmp) {
      this.phaseSepTmp = phaseSepTmp;
      return this;
    }

    public Builder suctionPrs(double suctionPrs) {
      this.suctionPrs = suctionPrs;
      return this;
    }

    public Builder suctiontmp_M(double suctiontmp_M) {
      this.suctiontmp_M = suctiontmp_M;
      return this;
    }

    public Builder suctiontmp_P(double suctiontmp_P) {
      this.suctiontmp_P = suctiontmp_P;
      return this;
    }

    public Builder surgeTankTmp(double surgeTankTmp) {
      this.surgeTankTmp = surgeTankTmp;
      return this;
    }

    public Builder waterInTmp(double waterInTmp) {
      this.waterInTmp = waterInTmp;
      return this;
    }

    public Builder waterOutTmp(double waterOutTmp) {
      this.waterOutTmp = waterOutTmp;
      return this;
    }

    public Refrig_Cryo6Telemetry build() {
      return new Refrig_Cryo6Telemetry(afterCoolTmp, compCurrent, compPower, compVoltage, dischrgPrs, dischrgtmp_M, dischrgtmp_P, fanSpeed, oilLevel, oilSepTmp, phaseSepTmp, suctionPrs, suctiontmp_M, suctiontmp_P, surgeTankTmp, waterInTmp, waterOutTmp);
    }
  }
}
